var ffmpeg = require('../lib/ffmpeg').Ffmpeg;

exports.testSimpleArgs = function(test) {
  var numberOfParams = 5 * 2;
  var proc = new ffmpeg('/var/www/v_vxxxxxxxxxxxxxxx_d_000000.mov')
    .withVideoBitrate(1024)
    .withVideoCodec('divx')
    .withAudioBitrate('128k')
    .toFormat('avi')
    .getArgs();
    
  test.ok(proc.length == numberOfParams);
  test.done();
};

exports.testComplexArgs = function(test) {
  var numberOfParams = 16;
  var proc = new ffmpeg('/var/www/v_vxxxxxxxxxxxxxxx_d_000000.mov')
    .withVideoBitrate(1024)
    .withVideoCodec('divx')
    .withAudioBitrate(256)
    .withAudioChannels(2)
    .addOption('-flags')
    .addOptions([ '+chroma', '+mixed_refs', '-qcomp 0.6' ])
    .getArgs();
    
  test.ok(proc.length == numberOfParams);
  test.done();
}

exports.testPreset = function(test) {
  var proc = new ffmpeg('/var/www/v_vxxxxxxxxxxxxxxx_d_000000.mov')
    .usingPreset('podcast')
    .getArgs();

  test.ok(proc.length > 17);
  test.done();
}

exports.testPresetOverride = function(test) {
  var proc = new ffmpeg('/var/www/v_vxxxxxxxxxxxxxxx_d_000000.mov')
    .usingPreset('podcast')
    .withSize('1024x768')
    .getArgs();
  
  test.ok(proc.indexOf('1024x768') > -1);
  test.done();
}

exports.testScreenshots = function(test) {
  var proc = new ffmpeg('/var/www/v_vxxxxxxxxxxxxxxx_d_000000.mov')
    .withSize('640x480')
    .takeScreenshots(5, '/var/www/testscreens', function(err) {
      test.ok(!err);
      test.done();
    });
};

/*
exports.testConversion = function(test) {
  var proc = new ffmpeg('/var/www/v_vxxxxxxxxxxxxxxx_d_000000.mov')
    .usingPreset('podcast')
    .saveToFile('/var/www/test_file.m4v', function(code, err) {
      test.ok(!err);
      test.done();
    });
};
*/

/*
exports.testStreamConversion = function(test) {
  var targetStream = require('fs').createWriteStream('/var/www/test_stream.flv');
  var proc = new ffmpeg('/var/www/v_vxxxxxxxxxxxxxxx_d_000000.mov')
    .usingPreset('flashvideo')
    .dumpCommand('stream')
    .writeToStream(targetStream, function(code, err) {
      targetStream.end();
      test.ok(!err);
      if (err)
        console.log(err);
      test.done();
    });
};
*/